@@ -12,19 +12,18 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GTK_ENTRY_BUFFER_H__
 #define __GTK_ENTRY_BUFFER_H__
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
 #include <glib-object.h>
+#include <gdk/gdk.h>
 
 G_BEGIN_DECLS
 
@@ -82,48 +81,62 @@ struct _GtkEntryBufferClass
                                           guint           n_chars);
 
   /* Padding for future expansion */
-  void (*_gtk_reserved0) (void);
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
   void (*_gtk_reserved3) (void);
   void (*_gtk_reserved4) (void);
   void (*_gtk_reserved5) (void);
+  void (*_gtk_reserved6) (void);
+  void (*_gtk_reserved7) (void);
+  void (*_gtk_reserved8) (void);
 };
 
+GDK_AVAILABLE_IN_ALL
 GType                     gtk_entry_buffer_get_type               (void) G_GNUC_CONST;
 
+GDK_AVAILABLE_IN_ALL
 GtkEntryBuffer*           gtk_entry_buffer_new                    (const gchar     *initial_chars,
                                                                    gint             n_initial_chars);
 
+GDK_AVAILABLE_IN_ALL
 gsize                     gtk_entry_buffer_get_bytes              (GtkEntryBuffer  *buffer);
 
+GDK_AVAILABLE_IN_ALL
 guint                     gtk_entry_buffer_get_length             (GtkEntryBuffer  *buffer);
 
+GDK_AVAILABLE_IN_ALL
 const gchar*              gtk_entry_buffer_get_text               (GtkEntryBuffer  *buffer);
 
+GDK_AVAILABLE_IN_ALL
 void                      gtk_entry_buffer_set_text               (GtkEntryBuffer  *buffer,
                                                                    const gchar     *chars,
                                                                    gint             n_chars);
 
+GDK_AVAILABLE_IN_ALL
 void                      gtk_entry_buffer_set_max_length         (GtkEntryBuffer  *buffer,
                                                                    gint             max_length);
 
+GDK_AVAILABLE_IN_ALL
 gint                      gtk_entry_buffer_get_max_length         (GtkEntryBuffer  *buffer);
 
+GDK_AVAILABLE_IN_ALL
 guint                     gtk_entry_buffer_insert_text            (GtkEntryBuffer  *buffer,
                                                                    guint            position,
                                                                    const gchar     *chars,
                                                                    gint             n_chars);
 
+GDK_AVAILABLE_IN_ALL
 guint                     gtk_entry_buffer_delete_text            (GtkEntryBuffer  *buffer,
                                                                    guint            position,
                                                                    gint             n_chars);
 
+GDK_AVAILABLE_IN_ALL
 void                      gtk_entry_buffer_emit_inserted_text     (GtkEntryBuffer  *buffer,
                                                                    guint            position,
                                                                    const gchar     *chars,
                                                                    guint            n_chars);
 
+GDK_AVAILABLE_IN_ALL
 void                      gtk_entry_buffer_emit_deleted_text      (GtkEntryBuffer  *buffer,
                                                                    guint            position,
                                                                    guint            n_chars);
